<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>SelectByHandle</name>
    <message>
        <source>Object selected: </source>
        <translation type="vanished">Objekt selektiert:</translation>
    </message>
    <message>
        <source>Object is not an entity: </source>
        <translation type="vanished">Objekt ist kein Zeichenelement:</translation>
    </message>
    <message>
        <location filename="../SelectByHandleInit.js" line="+2"/>
        <source>By Handle</source>
        <translation>Nach Objekthandle</translation>
    </message>
    <message>
        <location filename="../SelectByHandle.js" line="+58"/>
        <source>Object selected:</source>
        <translation>Objekt selektiert:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Object is not an entity:</source>
        <translation>Objekt ist kein Zeichenelement:</translation>
    </message>
</context>
<context>
    <name>SelectByHandleDialog</name>
    <message>
        <location filename="../SelectByHandleDialog.ui" line="+17"/>
        <source>Selection by Handle</source>
        <translation>Selektion nach Handle</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Handle (hex):</source>
        <translation>Handle (Hex):</translation>
    </message>
</context>
</TS>
